@@ -144,15 +144,16 @@ class DBConnect:
 
     def find_docu(self, find_dict: dict, many: bool = True) -> list:
         try:
-            find_dict = handle_db_id(find_dict)
-            find_dict = handle_db_remove(find_dict)
+            deep_find_dict = copy.deepcopy(find_dict)  # 深拷贝
+            deep_find_dict = handle_db_id(deep_find_dict)
+            deep_find_dict = handle_db_remove(deep_find_dict)
             if many:
                 # 多文档查询方式
-                query_cursor = self.mongo_collection.find(find_dict)
+                query_cursor = self.mongo_collection.find(deep_find_dict)
                 return handle_db_to_list(query_cursor)
             else:
                 # 单文档查询方式
-                query_dict = self.mongo_collection.find_one(find_dict)
+                query_dict = self.mongo_collection.find_one(deep_find_dict)
                 if not query_dict:
                     return []
                 return [handle_db_dict(query_dict)]
