@@ -47,7 +47,20 @@ class Parameter():
             try:
                 str_data = None
                 if type(_v) != verify[_k]:
-                    str_data = f'参数 {_k} 应该是 {verify[_k]} 类型'
+                    if verify[_k] == float:
+                        # 特殊处理字符串形式 float 类型判断
+                        try:
+                            checking[_k] = float(_v)
+                        except ValueError as err:
+                            str_data = f'参数 {_k} 应该符合 {verify[_k]} 格式'
+                    elif verify[_k] == int:
+                        # 特殊处理字符串形式 int 类型判断
+                        try:
+                            checking[_k] = int(_v)
+                        except ValueError as err:
+                            str_data = f'参数 {_k} 应该符合 {verify[_k]} 格式'
+                    else:
+                        str_data = f'参数 {_k} 应该是 {verify[_k]} 类型'
                 if not null_value and verify[_k] == str and not optional.__contains__(_k):
                     if not _v.strip():
                         str_data = f'参数 {_k} 不能是空字符串'
