@@ -19,11 +19,14 @@ class VerifyToken:
         threading.Thread(target=self.add_permission_db,
                          args=(per_defaults, )).start()
         self.uid = ''
-        self.redis_db = os.environ.get('REDIS_DB', 6013)
+        self.redis_db_permission = os.environ.get('REDIS_DB_PERMISSION', 6013)
         self.secret_key = os.environ.get(
-            'SECRET_KEY', 'dsfsdfs@#$#@FDgfdgdg325423523525fsdfg*')
-        self.expiration = os.environ.get('EXPIRATION', 3600)
-        self.redis_connect = RedisConnect(self.redis_db)
+            'SECRET_KEY', 'dsfsdfs@#$#@FDgfdgdg325423523525fsdfg*')  # 密钥
+        self.expiration = os.environ.get('EXPIRATION', 3600)  # 超时时间
+        self.redis_connect = RedisConnect(self.redis_db_permission)
+        self.mongo_db_name = os.environ.get('MONGODB_DB_NAME', 'universal')
+        self.mongo_permission = os.environ.get(
+            'MONGODB_PERMISSION', 'permission')
 
     def verify_token(self, request):
         """验证token"""
@@ -53,10 +56,11 @@ class VerifyToken:
         # 添加权限中心/名称到权限管理
         try:
             for per in per_defaults:
-                db = DBConnect(db='universal', collection='permission')
+                db = DBConnect(db=self.mongo_db_name,
+                               collection=self.mongo_permission)
                 # 查询是否已存在
-                find_dict = {'center_name': per.center_name,
-                             'permission_name': per.permission_name}
+                find_dict = {'center_name': str(per['center_name']),
+                             'permission_name': str(per['permission_name'])}
                 sear_permission = db.find_docu(
                     find_dict=find_dict, many=False)
                 if not sear_permission:
